class CacheRedis {

    constructor({client, prefixKey, expirationTime, isJson, deserializeFunc}) {
        this.client = client;
        this.prefixKey = prefixKey;
        this.expirationTime = expirationTime;
        this.isJson = isJson;
        this.deserializeFunc = deserializeFunc;
    }

    formatKey(key) {
        if (this.prefixKey) {
            return `${this.prefixKey}:${key}`;
        }

        return key;
    }

    async deserialize(data) {
        if (this.deserializeFunc) {
            return this.deserializeFunc(data);
        }

        return data;
    }

    async get(key) {
        const formattedKey = this.formatKey(key);
        console.time(formattedKey);
        const value = await this.client.getValue(formattedKey, this.isJson);
        console.timeEnd(formattedKey);
        return this.deserialize(value);
    }

    async set(key, value) {
        const formattedKey = this.formatKey(key);
        console.time(formattedKey);
        if (this.expirationTime) {
            const promise = await this.client.setValueWithExpirationTime(formattedKey, value, this.isJson, this.expirationTime);
            console.timeEnd(formattedKey);
            return promise;
        }
        const promise = await this.client.setValue(formattedKey, value, this.isJson);
        console.timeEnd(formattedKey);
        return promise;
    }

}

module.exports = {CacheRedis};
